@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Tester;
 # ABSTRACT: testing library for Dist::Zilla::App
-$Dist::Zilla::App::Tester::VERSION = '5.045';
+$Dist::Zilla::App::Tester::VERSION = '5.046';
 use parent 'App::Cmd::Tester::CaptureExternal';
 use App::Cmd::Tester 0.306 (); # result_class, ->app
 
@@ -25,7 +25,7 @@ sub test_dzil {
   my ($self, $source, $argv, $arg) = @_;
   $arg ||= {};
 
-  local @INC = map {; ref ? $_ : File::Spec->rel2abs($_) } @INC;
+  local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
   my $tmpdir = $arg->{tempdir} || File::Temp::tempdir(CLEANUP => 1);
   my $root   = dir($tmpdir)->subdir('source');
@@ -44,7 +44,7 @@ sub test_dzil {
 
 {
   package Dist::Zilla::App::Tester::Result;
-$Dist::Zilla::App::Tester::Result::VERSION = '5.045';
+$Dist::Zilla::App::Tester::Result::VERSION = '5.046';
 BEGIN { our @ISA = qw(App::Cmd::Tester::Result); }
 
   sub tempdir {
@@ -93,7 +93,7 @@ Dist::Zilla::App::Tester - testing library for Dist::Zilla::App
 
 =head1 VERSION
 
-version 5.045
+version 5.046
 
 =head1 AUTHOR
 
