@@ -1,6 +1,6 @@
 package Dist::Zilla::Tester;
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
-$Dist::Zilla::Tester::VERSION = '5.045';
+$Dist::Zilla::Tester::VERSION = '5.046';
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
 
@@ -113,7 +113,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 
 {
   package Dist::Zilla::Tester::_Builder;
-$Dist::Zilla::Tester::_Builder::VERSION = '5.045';
+$Dist::Zilla::Tester::_Builder::VERSION = '5.046';
 use Moose;
   extends 'Dist::Zilla::Dist::Builder';
   with 'Dist::Zilla::Tester::_Role';
@@ -172,7 +172,7 @@ use Moose;
 
     $Log_Events = $arg->{chrome}->logger->events;
 
-    local @INC = map {; ref ? $_ : File::Spec->rel2abs($_) } @INC;
+    local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
     local $ENV{DZIL_GLOBAL_CONFIG_ROOT};
     $ENV{DZIL_GLOBAL_CONFIG_ROOT} = $tester_arg->{global_config_root}
@@ -227,7 +227,7 @@ use Moose;
 
 {
   package Dist::Zilla::Tester::_Minter;
-$Dist::Zilla::Tester::_Minter::VERSION = '5.045';
+$Dist::Zilla::Tester::_Minter::VERSION = '5.046';
 use Moose;
   extends 'Dist::Zilla::Dist::Minter';
   with 'Dist::Zilla::Tester::_Role';
@@ -292,7 +292,7 @@ use Moose;
     local $arg->{chrome} = Dist::Zilla::Chrome::Test->new;
     $Log_Events = $arg->{chrome}->logger->events;
 
-    local @INC = map {; ref ? $_ : File::Spec->rel2abs($_) } @INC;
+    local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
     my $global_config_root = Path::Class::dir($tester_arg->{global_config_root})->absolute;
 
@@ -331,7 +331,7 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 5.045
+version 5.046
 
 =head1 AUTHOR
 
